@@ -38,8 +38,6 @@ from tipg.settings import (
 
 from fastapi import FastAPI
 
-from starlette.requests import Request
-
 mvt_settings = MVTSettings()
 features_settings = FeaturesSettings()
 
@@ -326,12 +324,12 @@ class Collection(BaseModel, metaclass=abc.ABCMeta):
         return {**geoms, **props}
 
     @abc.abstractmethod
-    async def features(self, request: Request, *args, **kwargs) -> ItemList:
+    async def features(self, *args, **kwargs) -> ItemList:
         """Get Items."""
         ...
 
     @abc.abstractmethod
-    async def get_tile(self, request: Request, *args, **kwargs) -> bytes:
+    async def get_tile(self, *args, **kwargs) -> bytes:
         """Get MVT Tile."""
         ...
 
@@ -777,7 +775,7 @@ class PgCollection(Collection):
 
     async def features(
         self,
-        request: Request,
+        conn: asyncpg.Connection,
         *,
         ids_filter: Optional[List[str]] = None,
         bbox_filter: Optional[List[float]] = None,
@@ -809,41 +807,40 @@ class PgCollection(Collection):
                 f"Limit can not be set higher than the `tipg_max_features_per_query` setting of {features_settings.max_features_per_query}"
             )
 
-        async with request.app.state.pool.acquire() as conn:
-            matched = await self._features_count_query(
+        matched = await self._features_count_query(
+            conn,
+            ids_filter=ids_filter,
+            datetime_filter=datetime_filter,
+            bbox_filter=bbox_filter,
+            properties_filter=properties_filter,
+            function_parameters=function_parameters,
+            cql_filter=cql_filter,
+            geom=geom,
+            dt=dt,
+        )
+
+        features = [
+            f
+            async for f in self._features_query(
                 conn,
                 ids_filter=ids_filter,
                 datetime_filter=datetime_filter,
                 bbox_filter=bbox_filter,
                 properties_filter=properties_filter,
-                function_parameters=function_parameters,
                 cql_filter=cql_filter,
+                sortby=sortby,
+                properties=properties,
                 geom=geom,
                 dt=dt,
+                limit=limit,
+                offset=offset,
+                bbox_only=bbox_only,
+                simplify=simplify,
+                geom_as_wkt=geom_as_wkt,
+                function_parameters=function_parameters,
             )
-
-            features = [
-                f
-                async for f in self._features_query(
-                    conn,
-                    ids_filter=ids_filter,
-                    datetime_filter=datetime_filter,
-                    bbox_filter=bbox_filter,
-                    properties_filter=properties_filter,
-                    cql_filter=cql_filter,
-                    sortby=sortby,
-                    properties=properties,
-                    geom=geom,
-                    dt=dt,
-                    limit=limit,
-                    offset=offset,
-                    bbox_only=bbox_only,
-                    simplify=simplify,
-                    geom_as_wkt=geom_as_wkt,
-                    function_parameters=function_parameters,
-                )
-            ]
-            returned = len(features)
+        ]
+        returned = len(features)
 
         return ItemList(
             items=features,
@@ -854,7 +851,7 @@ class PgCollection(Collection):
 
     async def get_tile(
         self,
-        request: Request,
+        conn: asyncpg.Connection,
         *,
         tms: TileMatrixSet,
         tile: Tile,
@@ -915,14 +912,13 @@ class PgCollection(Collection):
         )
         debug_query(q, *p)
 
-        async with request.app.state.pool.acquire() as conn:
-            tile = await conn.fetchval(q, *p)
+        tile = await conn.fetchval(q, *p)
 
         return bytes(tile)
 
 
 async def pg_get_collection_index(  # noqa: C901
-    db_pool: asyncpg.BuildPgPool,
+    conn: asyncpg.Connection,
     settings: Optional[DatabaseSettings] = None,
 ) -> List[Collection]:
     """Fetch Table and Functions index."""
@@ -946,86 +942,85 @@ async def pg_get_collection_index(  # noqa: C901
         );
     """  # noqa: W605
 
-    async with db_pool.acquire() as conn:
-        rows = await conn.fetch_b(
-            query,
-            schemas=schemas,
-            tables=settings.tables,
-            exclude_tables=settings.exclude_tables,
-            exclude_table_schemas=settings.exclude_table_schemas,
-            functions=settings.functions,
-            exclude_functions=settings.exclude_functions,
-            exclude_function_schemas=settings.exclude_function_schemas,
-            spatial=settings.only_spatial_tables,
-            spatial_extent=settings.spatial_extent,
-            datetime_extent=settings.datetime_extent,
+    rows = await conn.fetch_b(
+        query,
+        schemas=schemas,
+        tables=settings.tables,
+        exclude_tables=settings.exclude_tables,
+        exclude_table_schemas=settings.exclude_table_schemas,
+        functions=settings.functions,
+        exclude_functions=settings.exclude_functions,
+        exclude_function_schemas=settings.exclude_function_schemas,
+        spatial=settings.only_spatial_tables,
+        spatial_extent=settings.spatial_extent,
+        datetime_extent=settings.datetime_extent,
+    )
+
+    collections: List[Collection] = []
+    table_settings = TableSettings()
+    table_confs = table_settings.table_config
+    fallback_key_names = table_settings.fallback_key_names
+
+    for row in rows:
+        table = row[0]
+        table_id = table["schema"] + "." + table["name"]
+        confid = table["schema"] + "_" + table["name"]
+
+        if table_id == f"{settings.tipg_schema}.tipg_catalog":
+            continue
+
+        table_conf = table_confs.get(confid, TableConfig())
+
+        # Make sure that any properties set in conf exist in table
+        columns = table.get("properties", [])
+        if table_settings.sort_columns:
+            columns = sorted(columns, key=lambda d: d["name"])
+
+        properties_setting = table_conf.properties or [c["name"] for c in columns]
+
+        # ID Column
+        id_column = None
+        if id_name := table_conf.pk or table.get("pk"):
+            for p in columns:
+                if id_name == p["name"]:
+                    id_column = p
+                    break
+
+        if id_column is None and fallback_key_names:
+            for p in columns:
+                if p["name"] in fallback_key_names:
+                    id_column = p
+                    break
+
+        datetime_column = None
+        geometry_column = None
+
+        for c in columns:
+            if c.get("type") in ("timestamp", "timestamptz", "date"):
+                if table_conf.datetimecol == c["name"] or datetime_column is None:
+                    datetime_column = c
+
+            if c.get("type") in ("geometry", "geography"):
+                if table_conf.geomcol == c["name"] or geometry_column is None:
+                    geometry_column = c
+
+        collections.append(
+            PgCollection(
+                type=table["entity"],
+                id=table_id,
+                table=table["name"],
+                schema=table["schema"],
+                description=table.get("description", None),
+                table_columns=columns,
+                properties=[p for p in columns if p["name"] in properties_setting],
+                id_column=id_column,
+                datetime_column=datetime_column,
+                geometry_column=geometry_column,
+                parameters=table.get("parameters") or [],
+            )
         )
 
-        collections: List[Collection] = []
-        table_settings = TableSettings()
-        table_confs = table_settings.table_config
-        fallback_key_names = table_settings.fallback_key_names
-
-        for row in rows:
-            table = row[0]
-            table_id = table["schema"] + "." + table["name"]
-            confid = table["schema"] + "_" + table["name"]
-
-            if table_id == f"{settings.tipg_schema}.tipg_catalog":
-                continue
-
-            table_conf = table_confs.get(confid, TableConfig())
-
-            # Make sure that any properties set in conf exist in table
-            columns = table.get("properties", [])
-            if table_settings.sort_columns:
-                columns = sorted(columns, key=lambda d: d["name"])
-
-            properties_setting = table_conf.properties or [c["name"] for c in columns]
-
-            # ID Column
-            id_column = None
-            if id_name := table_conf.pk or table.get("pk"):
-                for p in columns:
-                    if id_name == p["name"]:
-                        id_column = p
-                        break
-
-            if id_column is None and fallback_key_names:
-                for p in columns:
-                    if p["name"] in fallback_key_names:
-                        id_column = p
-                        break
-
-            datetime_column = None
-            geometry_column = None
-
-            for c in columns:
-                if c.get("type") in ("timestamp", "timestamptz", "date"):
-                    if table_conf.datetimecol == c["name"] or datetime_column is None:
-                        datetime_column = c
-
-                if c.get("type") in ("geometry", "geography"):
-                    if table_conf.geomcol == c["name"] or geometry_column is None:
-                        geometry_column = c
-
-            collections.append(
-                PgCollection(
-                    type=table["entity"],
-                    id=table_id,
-                    table=table["name"],
-                    schema=table["schema"],
-                    description=table.get("description", None),
-                    table_columns=columns,
-                    properties=[p for p in columns if p["name"] in properties_setting],
-                    id_column=id_column,
-                    datetime_column=datetime_column,
-                    geometry_column=geometry_column,
-                    parameters=table.get("parameters") or [],
-                )
-            )
-
-        return collections
+    return collections
 
 
 async def register_collection_catalog(
@@ -1033,7 +1028,8 @@ async def register_collection_catalog(
     db_settings: Optional[DatabaseSettings] = None,
 ) -> None:
     """Register Table catalog."""
-    db_collections = await pg_get_collection_index(app.state.pool, settings=db_settings)
+    async with app.state.pool.acquire() as conn:
+        db_collections = await pg_get_collection_index(conn, settings=db_settings)
 
     app.state.collection_catalog = Catalog(
         collections={col.id: col for col in [*db_collections]},
